@@ -1,22 +1,22 @@
-require "puppet-syntax/version"
-require "puppet-syntax/manifests"
-require "puppet-syntax/templates"
-require "puppet-syntax/hiera"
-require "puppet/version"
+require 'puppet-syntax/version'
 
 module PuppetSyntax
+  autoload :Hiera, 'puppet-syntax/hiera'
+  autoload :Manifests, 'puppet-syntax/manifests'
+  autoload :Templates, 'puppet-syntax/templates'
+
   @exclude_paths = []
   @hieradata_paths = [
-    "**/data/**/*.*{yaml,yml}",
-    "hieradata/**/*.*{yaml,yml}",
-    "hiera*.*{yaml,yml}"
+    '**/data/**/*.*{yaml,yml}',
+    'hieradata/**/*.*{yaml,yml}',
+    'hiera*.*{yaml,yml}',
   ]
   @manifests_paths = [
-    '**/*.pp'
+    '**/*.pp',
   ]
   @templates_paths = [
     '**/templates/**/*.erb',
-    '**/templates/**/*.epp'
+    '**/templates/**/*.epp',
   ]
   @fail_on_deprecation_notices = true
   @check_hiera_keys = false
